@@ -53,9 +53,10 @@ class PlaidClient(BankingProvider):
             environment = environment or settings.plaid_env
         
         # Map environment string to Plaid Environment enum
+        # Note: Plaid only has Sandbox and Production (no Development in SDK)
         env_map = {
             "sandbox": plaid.Environment.Sandbox,
-            "development": plaid.Environment.Development,
+            "development": plaid.Environment.Sandbox,  # Map development to sandbox
             "production": plaid.Environment.Production,
         }
         host = env_map.get(environment or "sandbox", plaid.Environment.Sandbox)
@@ -75,7 +76,14 @@ class PlaidClient(BankingProvider):
         request = LinkTokenCreateRequest(
             user=LinkTokenCreateRequestUser(client_user_id=user_id),
             client_name="fin-infra",
-            products=[Products("auth"), Products("transactions")],
+            products=[
+                Products("auth"),           # Account/routing numbers for ACH
+                Products("transactions"),   # Transaction history
+                Products("liabilities"),    # Credit cards, loans, student loans
+                Products("investments"),    # Brokerage, retirement accounts
+                Products("assets"),         # Asset reports for lending/verification
+                Products("identity"),       # Account holder info (name, email, phone)
+            ],
             country_codes=[CountryCode("US")],
             language="en",
         )
