@@ -430,20 +430,6 @@ def add_recurring_detection(
     # Mount router
     app.include_router(router, include_in_schema=include_in_schema)
 
-    # Register scoped docs (if svc-infra available)
-    try:
-        from svc_infra.api.fastapi.docs.scoped import add_prefixed_docs
-
-        add_prefixed_docs(
-            app,
-            prefix=prefix,
-            title="Recurring Detection",
-            auto_exclude_from_root=True,
-            visible_envs=None,
-        )
-    except ImportError:
-        pass  # svc-infra not available, skip scoped docs
-
     return detector
 
 
