@@ -5,16 +5,25 @@ and repository implementations from templates for different financial domains.
 
 Typical usage:
     from fin_infra.scaffold.budgets import scaffold_budgets_core
+    from fin_infra.scaffold.holdings import scaffold_holdings_core
 
     result = scaffold_budgets_core(
         dest_dir=Path("app/models"),
         include_tenant=True,
         include_soft_delete=True,
     )
+    
+    result = scaffold_holdings_core(
+        dest_dir=Path("app/models/holdings"),
+        include_tenant=False,
+        include_soft_delete=False,
+    )
 """
 
 from .budgets import scaffold_budgets_core
+from .holdings import scaffold_holdings_core
 
 __all__ = [
     "scaffold_budgets_core",
+    "scaffold_holdings_core",
 ]
